@@ -32,22 +32,33 @@ def tok_pad(tokenizer):
     return 'pad'
 
 
-def handle_exceed(tokenizer, seq, maxlen, mode=['remove', 'slide', 'start_slice', 'end_slice']):
+def handle_exceed(tokenizer, seq, maxlen, mode=['noop', 'remove', 'slide', 'start_slice', 'end_slice'],
+                  keep_after_sep=True):
     mode = mode[0] if isinstance(mode, list) else mode
     seq = seq.replace("[MASK]", tok_mask(tokenizer)).replace("[SEP]", tok_sep(tokenizer)).replace("[CLS]",
                                                                                                   tok_begin(tokenizer))
     sep_split = seq.split(tok_sep(tokenizer))
-    ext_seq = [tok_sep(tokenizer)] + tokenizer.tokenize(sep_split[1]) if len(sep_split) > 1 else []
+    ext_seq = [tok_sep(tokenizer)] + tokenizer.tokenize(tok_sep(tokenizer).join(sep_split[1:])) \
+        if len(sep_split) > 1 and keep_after_sep else []
     t_seq = tokenizer.tokenize(sep_split[0])
+    if mode == 'noop':
+        return [t_seq + ext_seq], [[0, len(t_seq + ext_seq)]]
     if mode == 'remove':
-        ret_list = [t_seq] if len(t_seq) <= maxlen else []
-        return ret_list, [[0, 0]]
+        if len(t_seq + ext_seq) <= maxlen:
+            return [t_seq + ext_seq], [[0, len(t_seq + ext_seq)]]
+        else:
+            return [], [[0, 0]]
     if mode == 'slide':
         return nlp2.sliding_windows(t_seq, maxlen - len(ext_seq), append_seq=ext_seq)
     if mode == 'start_slice':
-        return [t_seq[:maxlen]], [[0, maxlen]]
+        slices = t_seq[:maxlen - len(ext_seq)]
+        slices.extend(ext_seq)
+        return [slices], [[0, maxlen - len(ext_seq)]]
     if mode == 'end_slice':
-        return [t_seq[len(t_seq) - maxlen:]], [[max(0, len(t_seq) - 512), len(t_seq)]]
+        start_pos = len(t_seq) + len(ext_seq) - maxlen
+        slices = t_seq[start_pos:]
+        slices.extend(ext_seq)
+        return [slices], [[max(0, start_pos), len(t_seq)]]
 
 
 def get_topP_unk_token(tokenizer, file_paths: list, topP: float):
